@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2017 Firetools Authors
+ * Copyright (C) 2015-2018 Firetools Authors
  *
  * This file is part of firetools project
  *
@@ -30,17 +30,17 @@ QList<Application> applist;
 
 Application::Application(const char *name, const char *description, const char *exec, const char *icon):
 	name_(name), description_(description), exec_(exec), icon_(icon) {
-	
+
 	app_icon_ = loadIcon(icon_);
 };
 
 Application::Application(QString name, QString description, QString exec, QString icon):
 	name_(name), description_(description), exec_(exec), icon_(icon) {
-	
+
 	app_icon_ = loadIcon(icon_);
 };
 
-// load an application from a desktop file
+// Load an application from a desktop file
 Application::Application(const char *name):
 	name_(name), description_("unknown"), exec_("unknown"), icon_("unknown") {
 
@@ -50,7 +50,7 @@ Application::Application(const char *name):
 	char *fname = get_config_file_name(name);
 	if (!fname)
 		return;
-	
+
 	if (arg_debug)
 		printf("loading %s\n", fname);
 
@@ -61,21 +61,21 @@ Application::Application(const char *name):
 		return;
 	}
 	free(fname);
-	
+
 	// read file
-#define MAXBUF 10000	
+#define MAXBUF 10000
 	char buf[MAXBUF];
 	while (fgets(buf, MAXBUF, fp)) {
 		// remove '\n'
 		char *ptr = strchr(buf, '\n');
 		if (ptr)
 			*ptr = '\0';
-		
+
 		// skip blancs
 		char *start = buf;
 		while (*start == ' ' || *start == '\t')
 			start++;
-		
+
 		// parse
 		if (strncmp(buf, "Comment=", 8) == 0)
 				description_ = buf + 8;
@@ -89,12 +89,13 @@ Application::Application(const char *name):
 	app_icon_ = loadIcon(icon_);
 }
 
+// Save the app's configuration
 int Application::saveConfig() {
 	char *fname = get_config_file_name(name_.toLocal8Bit().constData());
 	if (!fname)
 		return 1;
-	
-	// open file
+
+	// Open a file
 	FILE *fp = fopen(fname, "w");
 	if (!fp) {
 		free(fname);
@@ -108,29 +109,29 @@ int Application::saveConfig() {
 	fprintf(fp, "Icon=%s\n", icon_.toLocal8Bit().constData());
 	fprintf(fp, "Exec=%s\n", exec_.toLocal8Bit().constData());
 	fclose(fp);
-	
+
 	return 0;
 }
 
 /*
 From: http://standards.freedesktop.org/icon-theme-spec/icon-theme-spec-latest.html
 
-Icons and themes are looked for in a set of directories. By default, apps should look 
+Icons and themes are looked for in a set of directories. By default, apps should look
 in $HOME/.icons (for backwards compatibility), in $XDG_DATA_DIRS/icons and in /
-usr/share/pixmaps (in that order). Applications may further add their own icon 
-directories to this list, and users may extend or change the list (in application/desktop 
-specific ways).In each of these directories themes are stored as subdirectories. 
-A theme can be spread across several base directories by having subdirectories of 
+usr/share/pixmaps (in that order). Applications may further add their own icon
+directories to this list, and users may extend or change the list (in application/desktop
+specific ways).In each of these directories themes are stored as subdirectories.
+A theme can be spread across several base directories by having subdirectories of
 the same name. This way users can extend and override system themes.
 
-In order to have a place for third party applications to install their icons there 
-should always exist a theme called "hicolor" [1]. The data for the hicolor theme is 
+In order to have a place for third party applications to install their icons there
+should always exist a theme called "hicolor" [1]. The data for the hicolor theme is
 available for download at: http://www.freedesktop.org/software/icon-theme/. I
-mplementations are required to look in the "hicolor" theme if an icon was not found 
-in the current theme. 
+mplementations are required to look in the "hicolor" theme if an icon was not found
+in the current theme.
 */
 
-// compare strings 
+// compare strings
 static inline bool compare_ignore_case(QString q1, QString q2) {
 	q1 = q1.toLower();
 	q2 = q2.toLower();
@@ -159,16 +160,16 @@ static QIcon resize48x48(QIcon icon) {
 	QPixmap pix = icon.pixmap(sz.height(), sz.width());
 	QPixmap pixin;
 	int delta = 0;
-	
+
 	if (sz.height() ==  sz.width() && sz.height() <= 40) {
 		pixin = pix.scaled(40, 40);
 		delta = 12;
 	}
-	else {	
+	else {
 		pixin = pix.scaled(48, 48);
 		delta = 8;
 	}
-	
+
 
 	QPixmap pixout(64, 64);
 	pixout.fill(QColor(0, 0, 0, 0));
@@ -177,25 +178,25 @@ static QIcon resize48x48(QIcon icon) {
 	if (arg_debug)
 		printf("\t- output pixmap: w %d, h %d\n", pixout.width(), pixout.height());
 	paint->end();
-	return QIcon(pixout);		
+	return QIcon(pixout);
 }
 
 QIcon Application::loadIcon(QString name) {
 	if (arg_debug)
 		printf("searching icon %s\n", name.toLocal8Bit().data());
-	
+
 	if (name == ":resources/fstats" || name == ":resources/firejail-ui") {
 		if (arg_debug)
 			printf("\t- resource\n");
 		return QIcon(name); // not resized, using the real 64x64 size
 	}
-			
+
 	if (name.startsWith(":resources")) {
 		if (arg_debug)
 			printf("\t- resource\n");
 		return resize48x48(QIcon(name));
 	}
-	
+
 	if (name.startsWith('/')) {
 		if (arg_debug)
 			printf("\t- full path\n");
@@ -204,7 +205,7 @@ QIcon Application::loadIcon(QString name) {
 
 
 
-	// look for the file in firejail config directory under /home/user
+	// Look for the file in Firejail config directory under /home/user
 	QString conf = QDir::homePath() + "/.config/firetools/" + name + ".png";
 	QFileInfo checkFile1(conf);
 	if (checkFile1.exists() && checkFile1.isFile()) {
@@ -242,20 +243,20 @@ QIcon Application::loadIcon(QString name) {
 		if (!qstr.isEmpty())
 			return resize48x48(QIcon(qstr));
 	}
-	
+
 	{
 		QString qstr = walk("/usr/share/icons/hicolor/128x128", name);
 		if (!qstr.isEmpty())
 			return resize48x48(QIcon(qstr));
 	}
-	
+
 	{
 		QString qstr = walk("/usr/share/icons/hicolor/256x256", name);
 		if (!qstr.isEmpty())
 			return resize48x48(QIcon(qstr));
 	}
 
-	{	
+	{
 		QDirIterator it("/usr/share/pixmaps", QDirIterator::Subdirectories);
 		while (it.hasNext()) {
 			it.next();
@@ -267,8 +268,8 @@ QIcon Application::loadIcon(QString name) {
 				return resize48x48(icon);
 			}
 		}
-	}	
-	
+	}
+
 	if (QIcon::hasThemeIcon(name)) {
 		if (arg_debug)
 			printf("\t- fromTheme\n");
@@ -281,7 +282,7 @@ QIcon Application::loadIcon(QString name) {
 			return resize48x48(QIcon(qstr));
 	}
 
-	
+
 	// we failed to get an icon so far, look all over /usr/share/icons directory
 	{
 		QString qstr = walk("/usr/share/icons", name);
@@ -289,21 +290,40 @@ QIcon Application::loadIcon(QString name) {
 			return resize48x48(QIcon(qstr));
 	}
 
-	// create a new icon
+
+	// Create a new icon
 	if (arg_debug)
 		printf("\t- created\n");
+
+	// Create a new QPixmap instance for icons
 	QPixmap pix(64, 64);
-	pix.fill(Qt::red);
+
+	// Set the background color for generated icons
+	QColor iconBackgroundColor(68, 68, 68);
+
+	// Fill the icon with a color
+	pix.fill(iconBackgroundColor);
+
+
+	// Create a QPainter instance
 	QPainter painter( &pix );
+
+	// Set color and font for the painter
 	painter.setPen(Qt::white);
 	painter.setFont(QFont("Sans"));
+
+	// Draw application's name to the icon
 	painter.drawText(3, 20, name);
 	painter.end();
+
+	// Use generated pixmap as an icon
 	QIcon icon(pix);
+
 	return icon;
 }
 
 
+// Default application configurations for the app launcher
 struct DefaultApp {
 	const char *name;
 	const char *alias;
@@ -313,31 +333,32 @@ struct DefaultApp {
 };
 
 DefaultApp dapps[] = {
-	// firetools
+	// Firetools
 	{ "firetools", "", "Firetools", PACKAGE_LIBDIR "/fstats", ":resources/fstats" },
 	{ "firejail-ui", "", "Firejail Configuration Wizard", "firejail-ui", ":resources/firejail-ui" },
-	
-	// browser
+
+	// Web browsers
 	{ "iceweasel", "", "Debian Iceweasel", "firejail iceweasel", ":resources/firefox" },
 	{ "firefox", "iceweasel", "Mozilla Firefox", "firejail firefox", ":resources/firefox"},
 	{ "icecat", "firefox", "GNU IceCat", "firejail icecat", ":resources/firefox"},
 	{ "chromium", "", "Chromium Web Browser", "firejail chromium", "chromium"},
 	{ "chromium-browser", "chromium", "Chromium Web Browser", "firejail chromium-browser", "chromium-browser"},
+	{ "google-chrome", "", "Google Chrome", "firejail google-chrome", "google-chrome"},
 	{ "midori", "", "Midori Web Browser", "firejail midori", "midori" },
 	{ "opera", "", "Opera Web Browser", "firejail opera", "opera" },
 	{ "netsurf", "", "Netsurf Web Browser", "firejail netsurf", "netsurf" },
 
-	// mail
+	// Email clients
 	{ "icedove", "", "Debian Icedove", "firejail icedove", ":resources/icedove" },
 	{ "thunderbird", "icedove","Thunderbird", "firejail thunderbird", "thunderbird" },
 
-	// bittorrent
+	// Bittorrent
 	{ "transmission-gtk", "", "Transmission BitTorrent Client", "firejail transmission-gtk", "transmission" },
 	{ "transmission-qt", "transmission-gtk", "Transmission BitTorrent Client", "firejail transmission-qt", "transmission" },
 	{ "deluge", "", "Deluge BitTorrent Client", "firejail deluge", "deluge" },
 	{ "qbittorrent", "", "qBittorrent Client", "firejail qbittorrent", "qbittorrent" },
 
-	// viewers
+	// Viewers
 	{ "evince", "", "Evince PDF viewer", "firejail evince", "evince" },
 	{ "qpdfview", "", "qPDFView", "firejail qpdfview", "qpdfview" },
 	{ "xpdf", "", "Xpdf", "firejail xpdf", "xpdf" },
@@ -354,11 +375,11 @@ DefaultApp dapps[] = {
 	{ "calibre", "", "Calibre eBook reader", "firejail calibre", "/usr/share/calibre/images/lt.png" },
 	{ "xreader", "", "xreader", "firejail xreader", "xreader" },
 
-	// media players, audio/video tools
+	// Media players, audio/video tools
 	{ "xplayer", "", "xplayer", "firejail xplayer", "xplayer" },
 	{ "vlc", "", "VideoLAN Client", "firejail vlc", "vlc" },
 	{ "amarok", "", "Amarok", "firejail amarok", "amarok" },
-	{ "dragon", "", "Dragom Player", "firejail dragon", "dragonplayer" },
+	{ "dragon", "", "Dragon Player", "firejail dragon", "dragonplayer" },
 	{ "rhythmbox", "", "Rhythmbox", "firejail rhythmbox", "rhythmbox" },
 	{ "totem", "", "Totem", "firejail totem", "totem" },
 	{ "audacious", "", "Audacious", "firejail audacious", "audacious" },
@@ -371,7 +392,7 @@ DefaultApp dapps[] = {
 	{ "ghb", "", "HandBrake", "firejail ghb", "hb-icon" },
 	{ "audacity", "", "Audacity", "firejail audacity", "audacity" },
 
-	// editor
+	// Editors
 	{ "gimp", "", "Gimp", "firejail gimp", "gimp" },
 	{ "inkscape", "", "Inkscape", "firejail inkscape", "inkscape" },
 	{ "openshot", "", "OpenShot video editor", "firejail openshot", "openshot" },
@@ -379,19 +400,27 @@ DefaultApp dapps[] = {
 	{ "lowriter", "", "LibreOffice Writer", "firejail lowriter", ":resources/libreoffice-writer.png" },
 
 
-	// chat
+	// Chat
+	{ "signal-desktop", "", "Signal", "firejail signal-desktop", ":resources/signal-desktop.png" },
 	{ "pidgin", "", "Pidgin", "firejail pidgin", "pidgin" },
 	{ "xchat", "", "XChat", "firejail xchat", "xchat" },
 	{ "hexchat", "", "HexChat", "firejail hexchat", "hexchat" },
 	{ "quassel", "", "Quassel IRC", "firejail quassel", "quassel" },
 	{ "empathy", "", "Empathy", "firejail empathy", "empathy" },
-	
-	// etc
+
+	// Etc
 	{ "filezilla", "", "FileZilla", "firejail filezilla", "filezilla" },
 	{ "xterm", "", "xterm", "firejail xterm", ":resources/gnome-terminal.png" },
 	{ "urxvt", "", "rxvt-unicode", "firejail urxvt", "urxvt" },
-	
-	// games
+
+	// Pw managers
+	{ "keepass", "", "keepass", "firejail keepass", "keepass" },
+	{ "keepass2", "", "keepass2", "firejail keepass2", "keepass2" },
+	{ "keepassx", "", "keepassx", "firejail keepassx", "keepassx" },
+	{ "keepassx2", "", "keepassx2", "firejail keepassx2", "keepassx2" },
+	{ "keepassxc", "", "keepassxc", "firejail keepassxc", "keepassxc" },
+
+	// Games
 	{ "0ad", "", "0AD", "firejail 0ad", "0ad" },
 	{ "warzone2100", "", "Warzone 2100", "firejail warzone2100", "warzone2100" },
 	{ "etr", "", "Extreme Tux Racer", "firejail etr", "etr" },
@@ -399,7 +428,7 @@ DefaultApp dapps[] = {
 	{ "frozen-bubble", "", "Frozen-Bubble", "firejail frozen-bubble", "frozen-bubble" },
 	{ "2048-qt", "", "2048", "firejail 2048-qt", "2048-qt" },
 	{ "pingus", "", "Pingus", "firejail pingus", "pingus" },
-	
+
 	{ 0, 0, 0, 0, 0 }
 };
 
@@ -410,7 +439,7 @@ bool applications_check_default(const char *name) {
 			return true;
 		app++;
 	}
-	
+
 	return false;
 }
 
@@ -420,7 +449,7 @@ bool applist_check(QString name) {
 		if (it->name_ == name)
 			return true;
 	}
-	
+
 	return false;
 }
 
@@ -441,20 +470,26 @@ void applist_print() {
 
 void applications_init() {
 	// load default apps
+	if (arg_debug)
+		printf("Loading default applications\n");
+
 	DefaultApp *app = &dapps[0];
 	while (app->name != 0) {
-		// de we have the program?
+		if (arg_debug)
+			printf("checking %s\n", app->name);
+
+		// do we have the program?
 		if (which(app->name) == false) {
 			app++;
-			continue;			
+			continue;
 		}
-		
+
 		// is there an alias?
 		if (*app->alias != '\0' && which(app->alias)) {
 			app++;
 			continue;
 		}
-		
+
 		// is there a user config file?
 		if (have_config_file(app->name))
 			applist.append(Application(app->name));
@@ -463,7 +498,7 @@ void applications_init() {
 
 		app++;
 	}
-	
+
 	// load user apps from home directory
 	char *home = get_home_directory();
 	if (!home)
@@ -477,7 +512,7 @@ void applications_init() {
 		free(homecfg);
 		return;
 	}
-	
+
 	// walk home config directory
 	struct dirent *entry;
 	while ((entry = readdir(dir))) {
@@ -485,7 +520,7 @@ void applications_init() {
 			continue;
 		if (strcmp(entry->d_name, "..") == 0)
 			continue;
-		
+
 		// look only at .desktop files
 		int len = strlen(entry->d_name);
 		if (len <= 8)
@@ -498,7 +533,7 @@ void applications_init() {
 			free(fname);
 			continue;
 		}
-		
+
 		// check if the app is in default list
 		fflush(0);
 		*ending = '\0';
@@ -508,14 +543,14 @@ void applications_init() {
 			if (strcmp(fname, app->name) == 0) {
 				found = true;
 			}
-			
+
 			app++;
 		}
 		if (found) {
 			free(fname);
 			continue;
 		}
-		
+
 		// load file
 		applist.append(Application(fname));
 		free(fname);
