@@ -27,15 +27,18 @@
 
 #include <QUrl>
 #include <QProcess>
+#include <sys/types.h>
 #include <sys/utsname.h>
 #include <sys/mman.h>
 #include <sys/stat.h>        /* For mode constants */
 #include <fcntl.h>           /* For O_* constants */
 #include <unistd.h>
+#include <dirent.h>
 
 #include "stats_dialog.h"
 #include "db.h"
 #include "graph.h"
+#include "../common/common.h"
 #include "../common/utils.h"
 #include "../common/pid.h"
 #include "../../firetools_config.h"
@@ -50,24 +53,133 @@ static bool userNamespace(pid_t pid);
 static int getX11Display(pid_t pid);
 
 
-// find the first child process for the specified pid
-// return -1 if not found
+// from fdns:procs.c - void procs_list(void) {
+// returns malloc memory
+static char *find_fdns_shm_file_name(void) {
+	int procs_addr_default = 0;
+	int procs_addr_loopback = 0;
+	char *procs_addr_real = NULL;
+
+	DIR *dir;
+	if (!(dir = opendir("/run/fdns"))) {
+		// sleep 2 seconds and try again
+		sleep(2);
+		if (!(dir = opendir("/run/fdns")))
+			return 0;
+	}
+
+	struct dirent *entry;
+	int procs_addr_flag = 0;
+	while ((entry = readdir(dir))) {
+		if (*entry->d_name == '.')
+			continue;
+
+		char *fname;
+		if (asprintf(&fname, "/proc/%s", entry->d_name) == -1)
+			errExit("asprintf");
+		if (access(fname, R_OK) == 0) {
+			char *runfname;
+			if (asprintf(&runfname, "/run/fdns/%s", entry->d_name) == -1)
+				errExit("asprintf");
+			if (arg_debug)
+				printf("pid %s,", entry->d_name);
+			FILE *fp = fopen(runfname, "r");
+			if (fp) {
+				static const int MAXBUF = 1024;
+				char buf[MAXBUF];
+				if (fgets(buf, MAXBUF, fp)) {
+					char *ptr = strchr(buf, '\n');
+					if (ptr)
+						*ptr = '\0';
+
+					if (!procs_addr_flag) {
+						if (strcmp(buf, "127.1.1.1") == 0) {
+							procs_addr_default = 1;
+							procs_addr_flag = 1;
+						}
+						else if (strcmp(buf, "127.0.0.1") == 0) {
+							procs_addr_loopback = 1;
+							procs_addr_flag = 1;
+						}
+						else if (!procs_addr_real) {
+							procs_addr_real = strdup(buf);
+							if (!procs_addr_real)
+								errExit("strdup");
+						}
+					}
+				}
+			}
+			printf("\n");
+			fclose(fp);
+			free(runfname);
+		}
+		free(fname);
+	}
+	closedir(dir);
+
+	char *rv = 0;
+	if (procs_addr_default) {
+		rv = strdup("/dev/shm/fdns-stats-127.1.1.1");
+		if (!rv)
+			errExit("strdup");
+	}
+	else if (procs_addr_loopback) {
+		rv = strdup("/dev/shm/fdns-stats-127.0.0.1");
+		if (!rv)
+			errExit("strdup");
+	}
+	else if (procs_addr_real) {
+		if (asprintf(&rv, "/dev/shm/fdns-stats-%s", procs_addr_real) == -1)
+			errExit("asprintf");
+	}
+
+	if (procs_addr_real)
+		free(procs_addr_real);
+
+	return rv;
+}
+
+
+// dbus proxy path used by firejail and firemon
+#define XDG_DBUS_PROXY_PATH "/usr/bin/xdg-dbus-proxy"
 static int find_child(int id) {
 	int i;
+	int first_child = -1;
+	// find the first child
+	for (i = 0; i < max_pids && first_child == -1; i++) {
+		if (pids[i].level == 2 && pids[i].parent == id) {
+			// skip /usr/bin/xdg-dbus-proxy (started by firejail for dbus filtering)
+			char *cmdline = pid_proc_cmdline(i);
+			if (strncmp(cmdline, XDG_DBUS_PROXY_PATH, strlen(XDG_DBUS_PROXY_PATH)) == 0) {
+				free(cmdline);
+				continue;
+			}
+			free(cmdline);
+			first_child = i;
+			break;
+		}
+	}
+
+	if (first_child == -1)
+		return -1;
+
+	// find the second-level child
 	for (i = 0; i < max_pids; i++) {
-		if (pids[i].level == 2 && pids[i].parent == id)
+		if (pids[i].level == 3 && pids[i].parent == first_child)
 			return i;
 	}
 
-	return -1;
+	// if a second child is not found, return the first child pid
+	// this happens for processes sandboxed with --join
+	return first_child;
 }
 
-StatsDialog::StatsDialog(): QDialog(), fdns_report_(0), fdns_seq_(0), fdns_fd_(0), fdns_first_run_(true), fdns_cnt_(0),
+StatsDialog::StatsDialog(): QDialog(), fdns_report_(0), fdns_seq_(0), fdns_fd_(0), fdns_first_run_(true),
 		mode_(MODE_TOP), pid_(0), uid_(0), lts_(false),
 	pid_initialized_(false), pid_seccomp_(false), pid_caps_(QString("")), pid_noroot_(false),
 	pid_cpu_cores_(QString("")), pid_protocol_(QString("")), pid_name_(QString("")),
-	profile_(QString("")), pid_x11_(0),
-	have_join_(true), caps_cnt_(64), graph_type_(GRAPH_4MIN), net_none_(false) {
+	profile_(QString("")), pid_x11_(0), fdns_dump_(""),
+	have_join_(true), caps_cnt_(64), graph_type_(GRAPH_4MIN), net_none_(false), shm_file_name_(0) {
 
 	// clean storage area
 	cleanStorage();
@@ -193,6 +305,13 @@ QString StatsDialog::header() {
 	else if (mode_ == MODE_FDNS) {
 		msg += "<table><tr><td width=\"5\"></td><td>";
 		msg += "<a href=\"top\">Home</a>";
+		msg += "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<a href=\"dump\">Proxy</a>";
+		msg += "</td></tr></table>";
+	}
+	else if (mode_ == MODE_FDNS_DUMP) {
+		msg += "<table><tr><td width=\"5\"></td><td>";
+		msg += "<a href=\"top\">Home</a>";
+		msg += "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<a href=\"fdns\">Live</a>";
 		msg += "</td></tr></table>";
 	}
 
@@ -261,15 +380,135 @@ void StatsDialog::updateTop() {
 	procView_->setHtml(msg);
 }
 
+QString StatsDialog::printDump(int index) {
+	QString msg = "";
+	struct tm *t = localtime(&fdns_report_->tstamp[index]);
+	char *s;
+	if (asprintf(&s, "%02d:%02d:%02d ", t->tm_hour, t->tm_min, t->tm_sec) == -1)
+		errExit("asprintf");
+	if (strstr(fdns_report_->logentry[index], "dropped")) {
+		msg += "<font color=\"red\">";
+		msg += QString(s) + fdns_report_->logentry[index];
+		msg += "</font>";
+	}
+	else
+		msg += QString(s) + fdns_report_->logentry[index];
+
+	free(s);
+	msg += "<br/>";
+
+	return msg;
+}
+
+void StatsDialog::updateFdnsDump() {
+	if (!fdns_dump_.isEmpty())
+		return;
+	QString msg = header();
+
+	if (access(shm_file_name_, R_OK)) {
+		msg += QString("Error: cannot open shared memory, probably fdns is not running<br/>");
+		fdns_fd_ = 0;
+		procView_->setHtml(msg);
+		return;
+	}
+
+	int fd = ::open(shm_file_name_, O_RDONLY);
+	if (fd <= 0) {
+		msg +=  "Error: cannot access Firejail DNS data";
+		procView_->setHtml(msg);
+		return;
+
+	}
+
+	DnsReport report;
+	ssize_t len = ::read(fd, &report, sizeof(DnsReport));
+	if (len != sizeof(DnsReport)) {
+		msg += "Error: cannot access Firejail DNS data";
+		procView_->setHtml(msg);
+		return;
+	}
+	::close(fd);
+
+	QDateTime current = QDateTime::currentDateTime();
+	msg += "<b>Fireail DNS report for " + current.toString() + "</b><br/><br/>";
+
+	msg += "<b>Stats:</b><br/>";
+	msg += QString(fdns_report_->header1) + "<br/>";
+	msg += QString(fdns_report_->header2) + "<br/><br/>";
+
+
+	msg += "<b>Resolvers:</b><br/>";
+	for (int i = 0; i < fdns_report_->resolvers; i++) {
+		QString str= QString("Resolver %1: ").arg(i);
+		msg += str;
+		if (fdns_report_->encrypted[i]) {
+			char *s;
+			if (asprintf(&s, "connected to %d.%d.%d.%d<br/>", PRINT_IP(fdns_report_->peer_ip[i])) == -1)
+				errExit("asprintf");
+			QString str2 = s;
+			free(s);
+			msg += str2;
+		}
+		else
+			msg += "fallback mode<br/>";
+	}
+	msg += "<br/>";
+
+	msg += "<b>Process:</b><br/>";
+	QString qs = QString("PID: %1<br/>").arg(report.pid);
+	msg += qs;
+	qs = QString("Fallback server: %1<br/>").arg(report.fallback);
+	msg += qs;
+	if (report.disable_local_doh)
+		msg += "DoH disabled for applications behind the proxy<br/>";
+	else
+		msg += "DoH allowed for applications behind the proxy<br/>";
+	qs = QString("To shutdown the proxy run <b>\"sudo kill -9 %1\"</b> in a terminal<br/><br/>").arg(report.pid);
+	msg += qs;
+
+	msg += "<b>Queries:</b><br/>";
+	qs = QString("(queries cleared after %1 minutes)<br/>").arg(report.log_timeout);
+	msg += qs;
+	for (int i = fdns_report_->logindex; i < MAX_LOG_ENTRIES; i++) {
+		if (fdns_report_->tstamp && strlen(fdns_report_->logentry[i]))
+			msg += printDump(i);
+	}
+	for (int i = 0; i < fdns_report_->logindex; i++) {
+		if (fdns_report_->tstamp && strlen(fdns_report_->logentry[i]))
+			msg += printDump(i);
+	}
+
+	procView_->setHtml(msg);
+	fdns_dump_ = msg;
+	if (fdns_fd_)
+		::close(fdns_fd_);
+	fdns_fd_ = 0;
+	fdns_report_ = 0;
+}
+
+
 void StatsDialog::updateFdns() {
 	QString msg = header();
 
+	if (access(shm_file_name_, R_OK)) {
+		msg += QString("Error: cannot open shared memory, probably fdns is not running<br/>");
+		if (fdns_fd_)
+			::close(fdns_fd_);
+		fdns_fd_ = 0;
+		fdns_report_ = 0;
+		procView_->setHtml(msg);
+		return;
+	}
+
 	// open fdns shared memory if necessary
 	if (!fdns_fd_) {
-		fdns_fd_ = shm_open("/fdns-stats", O_RDONLY, S_IRWXU);
+		fdns_fd_ = shm_open(shm_file_name_ + 8, O_RDONLY, S_IRWXU);
 		if (fdns_fd_ == -1) {
-			msg += "Error: cannot open /dev/shm/fdns_stats, probably fdns is not running<br/>";
+			msg += "Error: cannot access shared memory, probably fdns is not running<br/>";
+			if (fdns_fd_)
+				::close(fdns_fd_);
 			fdns_fd_ = 0;
+			fdns_report_ = 0;
 			procView_->setHtml(msg);
 			return;
 		}
@@ -278,7 +517,7 @@ void StatsDialog::updateFdns() {
 	if (fdns_fd_ && fdns_report_ == 0) {
 		fdns_report_ = (DnsReport *) mmap(0, sizeof(DnsReport), PROT_READ, MAP_SHARED, fdns_fd_, 0 );
 		if (fdns_report_ == (void *) - 1) {
-			msg += "Error: cannot map /sdv/shm/fdns_stats file in process memory<<br/>";
+			msg += "Error: cannot map /dev/shm/fdns_stats file in process memory<<br/>";
 			fdns_report_ = 0;
 			::close(fdns_fd_);
 			fdns_fd_ = 0;
@@ -286,28 +525,39 @@ void StatsDialog::updateFdns() {
 			return;
 		}
 	}
+
 	if (fdns_fd_ && fdns_report_) {
-		if (fdns_first_run_ || fdns_cnt_++ >= 10 || fdns_seq_ != fdns_report_->seq) {
+		if (fdns_first_run_ || fdns_seq_ != fdns_report_->seq) {
 			fdns_first_run_ = false;
-			fdns_cnt_ = 0;
 			fdns_seq_ = fdns_report_->seq;
 
 			// print header
-			msg += fdns_report_->header;
-			msg += "<br/>";
+			msg += "<b>";
+			msg += fdns_report_->header1;
+			msg += "</b><br/><b>";
+			msg += fdns_report_->header2;
+			msg += "</b><br/><br/>";
 
 			// print log lines
-			for (int i = fdns_report_->logindex; i < MAX_LOG_ENTRIES; i++) {
-				msg += fdns_report_->logentry[i];
-				msg += "<br/>";
-			}
-			for (int i = 0; i < fdns_report_->logindex; i++) {
-				msg += fdns_report_->logentry[i];
-				msg += "<br/>";
+			int row = 24;
+			int i;
+			int logrows = MAX_LOG_ENTRIES;
+			if ((row - 4) > 0 && (row - 4) < MAX_LOG_ENTRIES)
+				logrows = row - 4;
+
+			int index = fdns_report_->logindex - logrows;
+			for (i = 0; i < logrows; i++, index++) {
+				int position = index;
+				if (index < 0)
+					position += MAX_LOG_ENTRIES;
+
+				if (fdns_report_->tstamp && strlen(fdns_report_->logentry[position]))
+					msg += printDump(position);
 			}
 			procView_->setHtml(msg);
 		}
 	}
+	procView_->update();
 }
 
 
@@ -350,7 +600,7 @@ void StatsDialog::updateTree() {
 
 	char *str = 0;
 	char *cmd;
-	if (asprintf(&cmd, "firemon --tree --nowrap %d", pid_) != -1) {
+	if (asprintf(&cmd, "firemon --tree --wrap %d", pid_) != -1) {
 		str = run_program(cmd);
 		char *ptr = str;
 		// htmlize!
@@ -529,8 +779,7 @@ static QString get_interfaces_old(int pid) {
 			ptr++;
 			char *child_dev = ptr;
 
-			QString str;
-			str.sprintf("%s (parent device %s", child_dev, parent_dev);
+			QString str = QString("%1 (parent device %2").arg(child_dev).arg(parent_dev);
 
 			// detect bridge device
 			char *sysfile;
@@ -967,6 +1216,8 @@ void StatsDialog::cycleReady() {
 		updateTop();
 	else if (mode_ == MODE_FDNS)
 		updateFdns();
+	else if (mode_ == MODE_FDNS_DUMP)
+		updateFdnsDump();
 	else if (mode_ == MODE_PID)
 		updatePid();
 	else if (mode_ == MODE_TREE)
@@ -1084,8 +1335,24 @@ void StatsDialog::anchorClicked(const QUrl & link) {
 		QMessageBox::about(this, tr("About"), msg);
 
 	}
-	else if (linkstr == "fdns")
+	else if (linkstr == "fdns") {
+		if (mode_ != MODE_FDNS_DUMP) {
+			if (shm_file_name_)
+				free(shm_file_name_);
+			shm_file_name_ = find_fdns_shm_file_name();
+			if (fdns_report_)
+				fdns_report_ = 0;
+			if (fdns_fd_) {
+				::close(fdns_fd_);
+				sleep(1); // give the kernel some time to close the shared mem file in order to open another one
+			}
+		}
 		mode_ = MODE_FDNS;
+	}
+	else if (linkstr == "dump") {
+		fdns_dump_ = QString("");
+		mode_ = MODE_FDNS_DUMP;
+	}
 	else if (linkstr == "newsandbox") {
 		// start firejail-ui as a separate process
 
